ace-editor {
  border-top: 10px solid #002B36;
  border-bottom: 10px solid #002B36;
}
ace-editor.full-screen > div {
  min-height: 100vh;
}
.ace_gutter {
  padding-right: 10px;
}
.ace_content {
  padding-left: 10px;
}

